@@ -247,6 +247,7 @@ class ClusterClient(
             host=host, port=int(port),
             conn_timeout=self._conn_timeout,
             read_timeout=self._read_timeout,
+            read_only=self._slave_ok,
             encoding=self._encoding,
             password=self._password,
             database=self._database
@@ -570,14 +571,20 @@ class SentinelClient(object):
     :param sentinels:
         Accepts a list of sentinels in this form: [('sentinel1', 26379), ('sentinel2', 26379), ('sentinel3', 26379)]
     :type sentinels: list
+
+    :param password:
+        Password used for authentication of Sentinel instance itself. If None, no authentication is done.
+        Only available starting with Redis 5.0.1.
+    :type password: str
     """
-    def __init__(self, sentinels):
+    def __init__(self, sentinels, password=None):
         self._conn = None
         self._sentinels = deque(sentinels)
+        self._password = password
 
     def _sentinel_connect(self, sentinel):
         host, port = sentinel
-        self._conn = Connection(host=host, port=port, conn_timeout=0.1, sentinel=True)
+        self._conn = Connection(host=host, port=port, conn_timeout=0.1, sentinel=True, password=self._password)
         try:
             self.execute('PING')
             return True
